import path from "path";
import dotenv from "dotenv";
import { Dialect } from "sequelize";
import { SequelizeOptions } from "sequelize-typescript";

class EnvHelper {
  public constructor() {
    // Determina quale file .env caricare
    const env = process.env.NODE_ENV || "development";
    const envFile = `.env.${env}`;
    console.log(path.resolve(envFile));
    // Carica le variabili d'ambiente dal file .env corretto
    dotenv.config({ path: path.resolve(envFile) });
  }

  public GetSequelizeOption(): SequelizeOptions {
    return {
      database: process.env.DB_DATABASE,
      username: process.env.DB_USERNAME,
      password: process.env.DB_PASSWORD,
      host: process.env.DB_HOST,
      port: parseInt(process.env.DB_PORT ?? "5433"),
      dialect: process.env.DB_DIALECT as Dialect,
      logging: process.env.DB_LOGGING == "true",
    };
  }
}

export const envHelper = new EnvHelper();