#!/usr/bin/env node
import express from "express";
import dotenv from "dotenv";
import { indexRouter } from "./routes/index.route";
import path from "path";
import { errorHandlingMiddleware } from "./middlewares/error.middleware";
import { dbSequelize } from "./configs/db.config";

const env = process.env.NODE_ENV || "development";
const envFile = `.env.${env}`;
dotenv.config({ path: path.resolve(envFile) });
const PORT = parseInt(process.env.API_PORT ?? "3001");

(async () => {
  await dbSequelize.authenticate();
  console.debug("Database Connection has been established successfully.");
})();

const app = express();
app.use("/", indexRouter);
app.listen(PORT, () => {
  console.log(`Server is running on http://localhost:${PORT}`);
  console.log(`Demo on http://localhost:${PORT}/info`);
});
app.use(errorHandlingMiddleware);

console.log("Hello, Node + TypeScript!");

